@@ -5,23 +5,9 @@
 * Date        : 2008-11-15
 * Description :Selection QGraphicsItem for the image viewer.
 *
-* Copyright (C) 2008 by Kare Sars <kare dot sars at iki dot fi>
+* SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
 *
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Lesser General Public
-* License as published by the Free Software Foundation; either
-* version 2.1 of the License, or (at your option) version 3, or any
-* later version accepted by the membership of KDE e.V. (or its
-* successor approved by the membership of KDE e.V.), which shall
-* act as a proxy defined in Section 6 of version 3 of the license.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 *
 * ============================================================ */
 #ifndef SELECTIONITEM_H
@@ -68,6 +54,8 @@ public:
     qreal devicePixelRatio() const;
     void setDevicePixelRatio(qreal dpr);
 
+    void setAddButtonEnabled(bool enabled);
+
 public:
     // Graphics Item methods
     QRectF boundingRect() const override;
